@@ -1,6 +1,5 @@
 package Net::SAML2::Protocol::Assertion;
 use Moose;
-use MooseX::Types::Moose qw/ Str HashRef ArrayRef /;
 use MooseX::Types::DateTime qw/ DateTime /;
 use MooseX::Types::Common::String qw/ NonEmptySimpleStr /;
 use DateTime;
@@ -11,14 +10,14 @@ use XML::XPath;
 with 'Net::SAML2::Role::ProtocolMessage';
 
 
-has 'attributes' => (isa => HashRef [ArrayRef], is => 'ro', required => 1);
-has 'session'    => (isa => Str,               is => 'ro', required => 1);
-has 'nameid'     => (isa => Str,               is => 'ro', required => 1);
+has 'attributes' => (isa => 'HashRef[ArrayRef]', is => 'ro', required => 1);
+has 'session'    => (isa => 'Str',               is => 'ro', required => 1);
+has 'nameid'     => (isa => 'Str',               is => 'ro', required => 1);
 has 'not_before' => (isa => DateTime,          is => 'ro', required => 1);
 has 'not_after'  => (isa => DateTime,          is => 'ro', required => 1);
 has 'audience'   => (isa => NonEmptySimpleStr, is => 'ro', required => 1);
 has 'xpath'      => (isa => 'XML::XPath', is => 'ro', required => 1);
-has 'in_response_to' => (isa => Str,           is => 'ro', required => 1);
+has 'in_response_to' => (isa => 'Str',           is => 'ro', required => 1);
 
 
 
@@ -114,7 +113,7 @@ Net::SAML2::Protocol::Assertion
 
 =head1 VERSION
 
-version 0.26
+version 0.27
 
 =head1 SYNOPSIS
 
