@@ -1,6 +1,5 @@
 package Net::SAML2::SP;
 use Moose;
-use MooseX::Types::Moose qw/ Str /;
 use MooseX::Types::URI qw/ Uri /;
 
 
@@ -15,16 +14,16 @@ use Net::SAML2::Protocol::LogoutRequest;
 
 
 has 'url'    => (isa => Uri, is => 'ro', required => 1, coerce => 1);
-has 'id'     => (isa => Str, is => 'ro', required => 1);
-has 'cert'   => (isa => Str, is => 'ro', required => 1);
-has 'key'    => (isa => Str, is => 'ro', required => 1);
+has 'id'     => (isa => 'Str', is => 'ro', required => 1);
+has 'cert'   => (isa => 'Str', is => 'ro', required => 1);
+has 'key'    => (isa => 'Str', is => 'ro', required => 1);
 has 'cacert' => (isa => 'Maybe[Str]', is => 'ro', required => 1);
 
-has 'org_name'         => (isa => Str, is => 'ro', required => 1);
-has 'org_display_name' => (isa => Str, is => 'ro', required => 1);
-has 'org_contact'      => (isa => Str, is => 'ro', required => 1);
+has 'org_name'         => (isa => 'Str', is => 'ro', required => 1);
+has 'org_display_name' => (isa => 'Str', is => 'ro', required => 1);
+has 'org_contact'      => (isa => 'Str', is => 'ro', required => 1);
 
-has '_cert_text' => (isa => Str, is => 'rw', required => 0);
+has '_cert_text' => (isa => 'Str', is => 'rw', required => 0);
 
 
 sub BUILD {
@@ -260,7 +259,7 @@ Net::SAML2::SP
 
 =head1 VERSION
 
-version 0.26
+version 0.27
 
 =head1 SYNOPSIS
 
